Anti-inflammatory Carrot & Fennel Soup - The Histamine Friendly Kitchen
Author: https://www.facebook.com/histaminefriendlykitchen
Description: As some of you probably already know by now I’m a huge soup lover 🙂 And this weeks recipe is one of my absolute favorites. And as an extra bonus this Anti-inflammatory Carrot & Fennel Soup, is the only way I can get my, lovely but very picky, hubby to eat anything with fennel 😉...Read More »
Date: 2017-10-19T09:32:00+00:00

- Skip to primary navigation
- Skip to main content
- Skip to primary sidebar
- Skip to footer

# Anti-inflammatory Carrot & Fennel Soup

October 19, 2017 by taniasurrow 2 Comments

As some of you probably already know by now I’m a huge soup lover 🙂 And this weeks recipe is one of my absolute favorites. And as an extra bonus this Anti-inflammatory Carrot & Fennel Soup, is the only way I can get my, lovely but very picky, hubby to eat anything with fennel 😉

It is really creamy, and gets a little kick from the added anti-inflammatory spices turmeric and ginger. I enjoy this soup as breakfast, lunch and dinner…. but then again I can eat soup for breakfast, lunch and dinner each day of the week 😉 Especially during the cold periods of the year. During the autumn and winter time this kind of thick vegetable soup is my go to breakfast, whereas smoothies and smoothie bowls is the favorite during the spring and summer.

Now for the recipe, chop up the (white) onion and the fennel. Add a little coconut oil to a big pot, and cook the onion and fennel till they turn translucent. Add some minced garlic if you like. Then clean the carrots and potatoes, slice up the carrots and cut the potatoes into cubes. Add the carrots and potatoes to the pot, give it a big stir before you add the bone broth and water.

As for the turmeric and ginger, I prefer to use the fresh roots instead of the dried spices. So if you can get your hand on the fresh stuff, do use it 🙂 I usually use about 10 g of each for this recipe. But if you want it to be pack a bigger punch, feel free to add more. I usually peel them, which is not really necessary, so feel free to leave the peel on. Two things enhances the absorption of curcumin (the active component in turmeric) and that is piperine (active component of black pepper) and fat. For optimal health benefits of turmeric, it can therefor be advised to add some black pepper, if tolerated.

Bring the soup to a boil, turn down the heat and let it simmer for about 30 minutes. When the carrots and potatoes are so soft that they fall of the fork when you prick them, the soup is ready to be blended. Blend till you get a smooth soup. Salt to taste and add the coconut milk, and bring the soup to a boil once again. Turn off the heat the moment the soups starts boiling, and now the soup is ready to be served 🙂 Enjoy this wonderful anti-inflammatory autumn soup with some toasted pumpkin seed. YUM o/

Print

## Anti-inflammatory Carrot & Fennel Soup

★★★★★ 5 from 1 reviews

- Author: Tania Surrow Larsen - The Histamine Friendly Kitchen
- Prep Time: 10 mins
- Cook Time: 40 mins
- Total Time: 50 mins
- Yield: 6-8 1x
- Category: Soup

Print
Pin

### Description

Creamy Anti-inflammatory Carrot & Fennel Soup with Turmeric and Ginger.

### Ingredients

- 2 (white) onions (ca. 175 g)
- 2 fennel bulbs (ca. 450 g)
- 10 medium-big carrots (ca. 900 g)
- 2 big potatoes (ca. 300 g)
- 10 g fresh ginger root*
- 10 g fresh turmeric root*
- 750 ml bone broth**
- 750 ml water**
- 150 ml coconut milk (1/2 cup + 2 tbsp)
- 1 tbsp coconut oil
- salt to taste

Toppings:

- a Handful of pumpkin seeds, toasted on a dry pan.

Cook Mode Prevent your screen from going dark

### Instructions

1. Chop up the (white) onion and the fennel. Add a little coconut oil to a big pot, and cook the onion and fennel till they turn translucent.
2. Clean the carrots and potatoes, slice up the carrots and cut the potatoes into cubes. Add the carrots and potatoes to the pot, give it a big stir before you add the bone broth and water.
3. As for the turmeric and ginger, I prefer to use the fresh roots instead of the dried spices. I usually use about 10 g of each for this recipe. But if you want it to be pack a bigger punch, feel free to add more.
4. Bring the soup to a boil, turn down the heat and let it simmer for about 30 minutes.
5. When the carrots and potatoes are so soft that they fall of the fork when you prick them, the soup is ready to be blended. Blend till you get a smooth soup.
6. Salt to taste.
7. Add the coconut milk, and bring the soup to a boil once again. Turn off the heat the moment the soups starts boiling, and the soup is ready to be served.
8. Enjoy this wonderful anti-inflammatory autumn soup with some toasted pumpkin seeds.

### Notes

* Add more if you want the soup to have more of a kick

** Or replace with a tolerated bouillon

Notes:
This recipe feeds 6-8 people, if you are cooking for less, you can either cut the recipe in half or freeze down the left overs. This soup freezes well.

Also please note that the nutritional data is an estimate at best, since I make my own bone broth. I normally don’t skim of the fat of my bone broth, which means that my soups probably also have a significantly higher fat content 😉

Mommy’s little helper <3

##

## If you love this Anti-inflammatory Carrot & Fennel Soup – You might also like:

Parsnip and Apple Soup

######

Simple Pumpkin Soup

######

Jerusalem Artichoke Soup

######

### References:

1. Recent Developments in Delivery, Bioavailability, Absorption and Metabolism of Curcumin: the Golden Pigment from Golden Spice. Sahdeo Prasad, PhD, Amit K. Tyagi, PhD, and Bharat B. Aggarwal, PhD. Cancer Res Treat. 2014 Jan; 46(1): 2–18.

Previous Post: « Histamine Friendly Creamy Beetroot Risotto with Lambs lettuce
Next Post: Pizza with Low Histamine Pesto and Fresh Figs »

## Reader Interactions

### Comments

1. Yvonne says

   November 16, 2017 at 14:27

   Made this recipe yesterday. I can’t eat potatoes because they increase my muscle spasms, substituted a white sweet potato. My 4 year old granddaughterate a huge bowl, my 15 month old twin granddaughters loved it and one kept signing more plus finally found a recipe my husband liked. Thanks for the great recipe.

   ★★★★★

   Reply

   - taniasurrow says

     November 16, 2017 at 16:13

     Thank you Yvonne for sharing your great substitution idea, and I’m over the moon happy to hear how well this dish was received 🙂 Lovely that you all loved it so much 🙂

     Reply

### Leave a Reply Cancel reply

Your email address will not be published. Required fields are marked *

Recipe rating ★☆ ★☆ ★☆ ★☆ ★☆

Comment *

Name *

Email *

Website

Δ

This site uses Akismet to reduce spam. Learn how your comment data is processed.